pub struct Model {Show 21 fields
pub id: Uuid,
pub parent_id: Option<Uuid>,
pub sequence: Option<i32>,
pub name: String,
pub status: String,
pub kind: String,
pub input: Option<Json>,
pub output: Option<Json>,
pub error: Option<String>,
pub max_retries: i32,
pub retry_count: i32,
pub cron: Option<String>,
pub next_run_at: Option<DateTimeWithTimeZone>,
pub queue_name: Option<String>,
pub executor_id: Option<String>,
pub app_version: Option<String>,
pub timeout_ms: Option<i64>,
pub deadline_epoch_ms: Option<i64>,
pub created_at: DateTimeWithTimeZone,
pub started_at: Option<DateTimeWithTimeZone>,
pub completed_at: Option<DateTimeWithTimeZone>,
}Fields
id: Uuidparent_id: Option<Uuid>sequence: Option<i32>name: Stringstatus: Stringkind: Stringinput: Option<Json>output: Option<Json>error: Option<String>max_retries: i32retry_count: i32cron: Option<String>next_run_at: Option<DateTimeWithTimeZone>queue_name: Option<String>executor_id: Option<String>app_version: Option<String>timeout_ms: Option<i64>deadline_epoch_ms: Option<i64>created_at: DateTimeWithTimeZonestarted_at: Option<DateTimeWithTimeZone>completed_at: Option<DateTimeWithTimeZone>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Model
impl<'de> Deserialize<'de> for Model
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Model> for ActiveModel
impl From<Model> for ActiveModel
Sourceimpl FromQueryResult for Model
impl FromQueryResult for Model
Sourcefn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
fn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
Instantiate a Model from a QueryResult Read more
Sourcefn from_query_result_optional(
res: &QueryResult,
pre: &str,
) -> Result<Option<Self>, DbErr>
fn from_query_result_optional( res: &QueryResult, pre: &str, ) -> Result<Option<Self>, DbErr>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option
Sourcefn from_query_result_nullable(
res: &QueryResult,
pre: &str,
) -> Result<Self, TryGetError>
fn from_query_result_nullable( res: &QueryResult, pre: &str, ) -> Result<Self, TryGetError>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option Read more
Sourcefn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
fn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
Sourceimpl IntoActiveModel<ActiveModel> for Model
impl IntoActiveModel<ActiveModel> for Model
Sourcefn into_active_model(self) -> ActiveModel
fn into_active_model(self) -> ActiveModel
Method to call to perform the conversion
Sourceimpl ModelTrait for Model
impl ModelTrait for Model
type Entity = Entity
Sourcefn get(&self, c: <Self::Entity as EntityTrait>::Column) -> Value
fn get(&self, c: <Self::Entity as EntityTrait>::Column) -> Value
Get the Value of a column from an Entity
Sourcefn set(&mut self, c: <Self::Entity as EntityTrait>::Column, v: Value)
fn set(&mut self, c: <Self::Entity as EntityTrait>::Column, v: Value)
Set the Value of a column in an Entity
Find related Models
Sourcefn delete<'a, 'async_trait, A, C>(
self,
db: &'a C,
) -> Pin<Box<dyn Future<Output = Result<DeleteResult, DbErr>> + Send + 'async_trait>>where
'a: 'async_trait,
Self: IntoActiveModel<A> + 'async_trait,
C: ConnectionTrait + 'async_trait,
A: ActiveModelTrait<Entity = Self::Entity> + ActiveModelBehavior + Send + 'a + 'async_trait,
fn delete<'a, 'async_trait, A, C>(
self,
db: &'a C,
) -> Pin<Box<dyn Future<Output = Result<DeleteResult, DbErr>> + Send + 'async_trait>>where
'a: 'async_trait,
Self: IntoActiveModel<A> + 'async_trait,
C: ConnectionTrait + 'async_trait,
A: ActiveModelTrait<Entity = Self::Entity> + ActiveModelBehavior + Send + 'a + 'async_trait,
Delete a model
Sourceimpl TryFrom<ActiveModel> for Model
impl TryFrom<ActiveModel> for Model
Sourceimpl TryIntoModel<Model> for ActiveModel
impl TryIntoModel<Model> for ActiveModel
impl Eq for Model
impl StructuralPartialEq for Model