pub struct SqlxPostgresPoolConnection { /* private fields */ }Expand description
Defines a sqlx PostgreSQL pool
Implementations
Sourceimpl SqlxPostgresPoolConnection
impl SqlxPostgresPoolConnection
Sourcepub async fn execute(&self, stmt: Statement) -> Result<ExecResult, DbErr>
pub async fn execute(&self, stmt: Statement) -> Result<ExecResult, DbErr>
Execute a Statement on a PostgreSQL backend
Sourcepub async fn execute_unprepared(&self, sql: &str) -> Result<ExecResult, DbErr>
pub async fn execute_unprepared(&self, sql: &str) -> Result<ExecResult, DbErr>
Execute an unprepared SQL statement on a PostgreSQL backend
Sourcepub async fn query_one(
&self,
stmt: Statement,
) -> Result<Option<QueryResult>, DbErr>
pub async fn query_one( &self, stmt: Statement, ) -> Result<Option<QueryResult>, DbErr>
Get one result from a SQL query. Returns Option::None if no match was found
Sourcepub async fn query_all(
&self,
stmt: Statement,
) -> Result<Vec<QueryResult>, DbErr>
pub async fn query_all( &self, stmt: Statement, ) -> Result<Vec<QueryResult>, DbErr>
Get the results of a query returning them as a Vec<QueryResult>
Sourcepub async fn stream(&self, stmt: Statement) -> Result<QueryStream, DbErr>
pub async fn stream(&self, stmt: Statement) -> Result<QueryStream, DbErr>
Stream the results of executing a SQL query
Sourcepub async fn begin(
&self,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<DatabaseTransaction, DbErr>
pub async fn begin( &self, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<DatabaseTransaction, DbErr>
Bundle a set of SQL statements that execute together.
Sourcepub async fn transaction<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>
pub async fn transaction<F, T, E>( &self, callback: F, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<T, TransactionError<E>>
Create a PostgreSQL transaction
Sourcepub async fn ping(&self) -> Result<(), DbErr>
pub async fn ping(&self) -> Result<(), DbErr>
Checks if a connection to the database is still valid.
Sourcepub async fn close(self) -> Result<(), DbErr>
pub async fn close(self) -> Result<(), DbErr>
Explicitly close the Postgres connection.
See Self::close_by_ref for usage with references.
Sourcepub async fn close_by_ref(&self) -> Result<(), DbErr>
pub async fn close_by_ref(&self) -> Result<(), DbErr>
Explicitly close the Postgres connection